A theme specifically designed for maps, with no grid and minimal elements, in the style of Cheysson's cartographic works.
Usage
theme_cheysson_map(
base_size = 11,
base_family = "auto",
title_family = "auto",
load_fonts = TRUE
)Examples
if (FALSE) { # \dontrun{
# Not run automatically: see theme_cheysson() for why (same font/grid crash)
# once a plot with this theme is actually rendered/printed.
# For use with spatial data/maps
library(ggplot2)
# Load fonts first
load_cheysson_fonts()
# Example with spatial data (requires sf package)
if (requireNamespace("sf", quietly = TRUE)) {
# ggplot(map_data) + geom_sf() + theme_cheysson_map()
}
} # }